# PaymentMethodCardBinInfoProductType

The product type of the card.

## Enum

* `COMMERCIAL_OR_CORPORATE_CARD` (value: `'Commercial_or_Corporate_Card'`)

* `CONSUMER_CARD` (value: `'Consumer_Card'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


